==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerListFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IssuerListFluent<A extends IssuerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Issuer item);
  public A setToItems(Integer index,Issuer item);
  public A addToItems(io.fabric8.certmanager.api.model.v1alpha3.Issuer... items);
  public A addAllToItems(Collection<Issuer> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.v1alpha3.Issuer... items);
  public A removeAllFromItems(Collection<Issuer> items);
  public A removeMatchingFromItems(Predicate<IssuerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Issuer> getItems();
  public List<Issuer> buildItems();
  public Issuer buildItem(Integer index);
  public Issuer buildFirstItem();
  public Issuer buildLastItem();
  public Issuer buildMatchingItem(Predicate<IssuerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IssuerBuilder> predicate);
  public A withItems(List<Issuer> items);
  public A withItems(io.fabric8.certmanager.api.model.v1alpha3.Issuer... items);
  public Boolean hasItems();
  public IssuerListFluent.ItemsNested<A> addNewItem();
  public IssuerListFluent.ItemsNested<A> addNewItemLike(Issuer item);
  public IssuerListFluent.ItemsNested<A> setNewItemLike(Integer index,Issuer item);
  public IssuerListFluent.ItemsNested<A> editItem(Integer index);
  public IssuerListFluent.ItemsNested<A> editFirstItem();
  public IssuerListFluent.ItemsNested<A> editLastItem();
  public IssuerListFluent.ItemsNested<A> editMatchingItem(Predicate<IssuerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,IssuerFluent<IssuerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerListFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IssuerListFluent<A extends IssuerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Issuer item);
  public A setToItems(int index,Issuer item);
  public A addToItems(io.fabric8.certmanager.api.model.v1alpha3.Issuer... items);
  public A addAllToItems(Collection<Issuer> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.v1alpha3.Issuer... items);
  public A removeAllFromItems(Collection<Issuer> items);
  public A removeMatchingFromItems(Predicate<IssuerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Issuer> getItems();
  public List<Issuer> buildItems();
  public Issuer buildItem(int index);
  public Issuer buildFirstItem();
  public Issuer buildLastItem();
  public Issuer buildMatchingItem(Predicate<IssuerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IssuerBuilder> predicate);
  public A withItems(List<Issuer> items);
  public A withItems(io.fabric8.certmanager.api.model.v1alpha3.Issuer... items);
  public Boolean hasItems();
  public IssuerListFluent.ItemsNested<A> addNewItem();
  public IssuerListFluent.ItemsNested<A> addNewItemLike(Issuer item);
  public IssuerListFluent.ItemsNested<A> setNewItemLike(int index,Issuer item);
  public IssuerListFluent.ItemsNested<A> editItem(int index);
  public IssuerListFluent.ItemsNested<A> editFirstItem();
  public IssuerListFluent.ItemsNested<A> editLastItem();
  public IssuerListFluent.ItemsNested<A> editMatchingItem(Predicate<IssuerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,IssuerFluent<IssuerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
